@@ -1,7 +1,7 @@
 #' @title Get T1 Image Filenames
 #'
 #' @description Return the filenames for the T1 images
-#' @param ... arguments to pass to \code{\link{get_image_filenames}},
+#' @param ... arguments to pass to \code{\link[kirby21.base]{get_image_filenames}},
 #' \code{modalities = "T1"} so it cannot be specified
 #' @return Vector of filenames
 #' 
@@ -13,3 +13,10 @@ get_t1_filenames = function(...) {
   x = kirby21.base::get_image_filenames(modalities = "T1", ...)
   return(x)
 }
+
+#' @export
+#' @rdname get_t1_filenames
+get_brainmask_filenames = function(...) {
+  x = kirby21.base::get_image_filenames(modalities = "BrainMask", ...)
+  return(x)
+}
